=======
Credits
=======

Development Lead
----------------

* `John Kitchin <https://github.com/jkitchin>`_
* `Michael E. Rose <https://github.com/Michael-E-Rose>`_

Contributors
------------

See `contributors <https://github.com/scopus-api/scopus/graphs/contributors>`_
